==> mingw-w64-arrow-16.1.0-4.src.tar.zst: apache-arrow-16.1.0/java/adapter/avro/src/main/java/org/apache/arrow/adapter/avro/consumers/AvroFixedConsumer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.arrow.adapter.avro.consumers;

import java.io.IOException;

import org.apache.arrow.vector.FixedSizeBinaryVector;
import org.apache.avro.io.Decoder;

/**
 * Consumer which consume fixed type values from avro decoder.
 * Write the data to {@link org.apache.arrow.vector.FixedSizeBinaryVector}.
 */
public class AvroFixedConsumer extends BaseAvroConsumer<FixedSizeBinaryVector> {

  private final byte[] reuseBytes;

  /**
   * Instantiate a AvroFixedConsumer.
   */
  public AvroFixedConsumer(FixedSizeBinaryVector vector, int size) {
    super(vector);
    reuseBytes = new byte[size];
  }

  @Override
  public void consume(Decoder decoder) throws IOException {
    decoder.readFixed(reuseBytes);
    vector.setSafe(currentIndex++, reuseBytes);
  }
}

==> mingw-w64-arrow-18.1.0-3.src.tar.zst: apache-arrow-18.1.0/java/adapter/avro/src/main/java/org/apache/arrow/adapter/avro/consumers/AvroFixedConsumer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.arrow.adapter.avro.consumers;

import java.io.IOException;
import org.apache.arrow.vector.FixedSizeBinaryVector;
import org.apache.avro.io.Decoder;

/**
 * Consumer which consume fixed type values from avro decoder. Write the data to {@link
 * org.apache.arrow.vector.FixedSizeBinaryVector}.
 */
public class AvroFixedConsumer extends BaseAvroConsumer<FixedSizeBinaryVector> {

  private final byte[] reuseBytes;

  /** Instantiate a AvroFixedConsumer. */
  public AvroFixedConsumer(FixedSizeBinaryVector vector, int size) {
    super(vector);
    reuseBytes = new byte[size];
  }

  @Override
  public void consume(Decoder decoder) throws IOException {
    decoder.readFixed(reuseBytes);
    vector.setSafe(currentIndex++, reuseBytes);
  }
}
